Implements the "/mmax" (min-max-arithmetical) recombination for the ExpDE framework
recombination_mmax(X, M, recpars = list(lambda = NULL))Matrix U containing the recombined population
population matrix (original)
population matrix (mutated)
recombination parameters (see Recombination parameters
for details)
This recombination operator evaluates 4*popsize candidate solutions
per iteration of the algorithm. The value of the nfe counter and the
vector of performance values G are updated in the calling environment.
The recpars parameter contains all parameters required to define the
recombination. recombination_pbest() understands the following
fields in recpars:
lambda : Recombination multiplier.
Optional. Defaults to NULL
Accepts numeric value 0 < lambda < 1 or
NULL (in which case a random value is
independently used for each variable of each
recombination pair).
F. Herrera, M. Lozano, A. M. Sanchez, "A taxonomy for the crossover
operator for real-coded genetic algorithms: an experimental study",
International Journal of Intelligent Systems 18(3):309-338, 2003.
F Herrera, M. Lozano, J.L. Verdegay, "Tuning fuzzy logic controllers by
genetic algorithms.", International Journal of Approximate Reasoning
12(3):299-315, 1995.